==> ui-18.1.2.tgz: package/components/button/Button.js <==
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import React from 'react';
import { LoadingOutlined } from '@react-devui/icons';
import { getClassName } from '@react-devui/utils';
import { useWave, useGeneralContext } from '../../hooks';
import { registerComponentMate, TTANSITION_DURING_SLOW } from '../../utils';
import { DBaseDesign } from '../_base-design';
import { DCollapseTransition } from '../_transition';
import { useComponentConfig, usePrefixConfig } from '../root';
const { COMPONENT_NAME } = registerComponentMate({ COMPONENT_NAME: 'DButton' });
function Button(props, ref) {
    const _a = useComponentConfig(COMPONENT_NAME, props), { children, dType = 'primary', dTheme = 'primary', dLoading = false, dBlock = false, dVariant, dSize, dIcon, dIconRight = false } = _a, restProps = __rest(_a, ["children", "dType", "dTheme", "dLoading", "dBlock", "dVariant", "dSize", "dIcon", "dIconRight"]);
    //#region Context
    const dPrefix = usePrefixConfig();
    const { gSize, gDisabled } = useGeneralContext();
    //#endregion
    const [waveNode, wave] = useWave();
    const size = dSize !== null && dSize !== void 0 ? dSize : gSize;
    const disabled = restProps.disabled || dLoading || gDisabled;
    const buttonIcon = (loading, iconRef, style) => (_jsx("div", Object.assign({ ref: iconRef, className: `${dPrefix}button__icon`, style: style }, { children: loading ? _jsx(LoadingOutlined, { dSpin: true }) : dIcon })));
    return (_jsx(DBaseDesign, Object.assign({ dComposeDesign: {
            disabled: disabled,
        }, dFormDesign: false }, { children: ({ render: renderBaseDesign }) => {
            var _a;
            return renderBaseDesign(_jsxs("button", Object.assign({}, restProps, { ref: ref, className: getClassName(restProps.className, `${dPrefix}button`, `${dPrefix}button--${dType}`, `t-${dTheme}`, {
                    [`${dPrefix}button--${dVariant}`]: dVariant,
                    [`${dPrefix}button--${size}`]: size,
                    [`${dPrefix}button--block`]: dBlock,
                    [`${dPrefix}button--icon`]: !children,
                    [`${dPrefix}button--icon-right`]: dIconRight,
                    'is-loading': dLoading,
                }), type: (_a = restProps.type) !== null && _a !== void 0 ? _a : 'button', disabled: disabled, onClick: (e) => {
                    var _a;
                    (_a = restProps.onClick) === null || _a === void 0 ? void 0 : _a.call(restProps, e);
                    if (dType === 'primary' || dType === 'secondary' || dType === 'outline' || dType === 'dashed') {
                        wave(`var(--${dPrefix}color-${dTheme})`);
                    }
                } }, { children: [dIcon ? (buttonIcon(dLoading)) : (_jsx(DCollapseTransition, Object.assign({ dOriginalSize: {
                            width: '',
                        }, dCollapsedStyle: {
                            width: 0,
                        }, dIn: dLoading, dDuring: TTANSITION_DURING_SLOW, dHorizontal: true, dStyles: {
                            entering: {
                                transition: ['width', 'padding', 'margin'].map((attr) => `${attr} ${TTANSITION_DURING_SLOW}ms linear`).join(', '),
                            },
                            leaving: {
                                transition: ['width', 'padding', 'margin'].map((attr) => `${attr} ${TTANSITION_DURING_SLOW}ms linear`).join(', '),
                            },
                            leaved: { display: 'none' },
                        }, dDestroyWhenLeaved: true }, { children: (collapseRef, collapseStyle) => buttonIcon(true, collapseRef, collapseStyle) }))), _jsx("div", { children: children }), waveNode] })));
        } })));
}
export const DButton = React.forwardRef(Button);

==> ui-18.5.4.tgz: package/components/button/Button.js <==
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import { jsx as _jsx, Fragment as _Fragment, jsxs as _jsxs } from "react/jsx-runtime";
import React from 'react';
import { LoadingOutlined } from '@react-devui/icons';
import { checkNodeExist, getClassName } from '@react-devui/utils';
import { useWave, useGeneralContext } from '../../hooks';
import { registerComponentMate, TTANSITION_DURING_SLOW } from '../../utils';
import { DBaseDesign } from '../_base-design';
import { DCollapseTransition } from '../_transition';
import { useComponentConfig, usePrefixConfig } from '../root';
const { COMPONENT_NAME } = registerComponentMate({ COMPONENT_NAME: 'DButton' });
function Button(props, ref) {
    const _a = useComponentConfig(COMPONENT_NAME, props), { children, dType = 'primary', dTheme = 'primary', dLoading = false, dBlock = false, dVariant, dSize, dIcon, dIconRight = false } = _a, restProps = __rest(_a, ["children", "dType", "dTheme", "dLoading", "dBlock", "dVariant", "dSize", "dIcon", "dIconRight"]);
    //#region Context
    const dPrefix = usePrefixConfig();
    const { gSize, gDisabled } = useGeneralContext();
    //#endregion
    const [waveNode, wave] = useWave();
    const size = dSize !== null && dSize !== void 0 ? dSize : gSize;
    const disabled = restProps.disabled || dLoading || gDisabled;
    const buttonIcon = (loading, iconRef, style) => (_jsx("div", Object.assign({ ref: iconRef, className: getClassName(`${dPrefix}button__icon`, {
            [`${dPrefix}button__icon--right`]: dIconRight,
        }), style: style }, { children: loading ? _jsx(LoadingOutlined, { dSpin: true }) : dIcon })));
    const iconNode = checkNodeExist(dIcon) ? (buttonIcon(dLoading)) : (_jsx(DCollapseTransition, Object.assign({ dOriginalSize: {
            width: '',
        }, dCollapsedStyle: {
            width: 0,
        }, dIn: dLoading, dDuring: TTANSITION_DURING_SLOW, dHorizontal: true, dStyles: {
            entering: {
                transition: ['width', 'padding', 'margin'].map((attr) => `${attr} ${TTANSITION_DURING_SLOW}ms linear`).join(', '),
            },
            leaving: {
                transition: ['width', 'padding', 'margin'].map((attr) => `${attr} ${TTANSITION_DURING_SLOW}ms linear`).join(', '),
            },
            leaved: { display: 'none' },
        }, dDestroyWhenLeaved: true }, { children: (collapseRef, collapseStyle) => buttonIcon(true, collapseRef, collapseStyle) })));
    const contentNode = _jsx("div", { children: children });
    return (_jsx(DBaseDesign, Object.assign({ dComposeDesign: {
            disabled: disabled,
        }, dFormDesign: false }, { children: ({ render: renderBaseDesign }) => {
            var _a;
            return renderBaseDesign(_jsxs("button", Object.assign({}, restProps, { ref: ref, className: getClassName(restProps.className, `${dPrefix}button`, `${dPrefix}button--${dType}`, `t-${dTheme}`, {
                    [`${dPrefix}button--${dVariant}`]: dVariant,
                    [`${dPrefix}button--${size}`]: size,
                    [`${dPrefix}button--block`]: dBlock,
                    [`${dPrefix}button--icon`]: !children,
                    'is-loading': dLoading,
                }), type: (_a = restProps.type) !== null && _a !== void 0 ? _a : 'button', disabled: disabled, onClick: (e) => {
                    var _a;
                    (_a = restProps.onClick) === null || _a === void 0 ? void 0 : _a.call(restProps, e);
                    if (dType === 'primary' || dType === 'secondary' || dType === 'outline' || dType === 'dashed') {
                        wave(`var(--${dPrefix}color-${dTheme})`);
                    }
                } }, { children: [dIconRight ? (_jsxs(_Fragment, { children: [contentNode, iconNode] })) : (_jsxs(_Fragment, { children: [iconNode, contentNode] })), waveNode] })));
        } })));
}
export const DButton = React.forwardRef(Button);
